@@ -562,7 +562,7 @@ read_metadata (TrackerResource      *metadata,
 	g_ptr_array_free (keywords, TRUE);
 
 	if (g_strcmp0(pd.software, "gnome-screenshot") == 0) {
-		tracker_resource_set_string (metadata, "nie:isPartOf", "nfo:image-category-screenshot");
+		tracker_resource_add_uri (metadata, "nie:isPartOf", "nfo:image-category-screenshot");
 	}
 
 	tracker_exif_free (ed);
@@ -587,7 +587,15 @@ guess_dlna_profile (gint          depth,
 		*dlna_mimetype = NULL;
 	}
 
-	profile = "PNG_LRG";
+	if (width == 120 && height == 120) {
+		profile = "PNG_LRG_ICO";
+	} else if (width == 48 && height == 48) {
+		profile = "PNG_SM_ICO";
+	} else if (width <= 160 && height <= 160) {
+		profile = "PNG_TN";
+	} else if (depth <= 32 && width <= 4096 && height <= 4096) {
+		profile = "PNG_LRG";
+	}
 
 	if (profile) {
 		if (dlna_profile) {
@@ -613,7 +621,7 @@ tracker_extract_get_metadata (TrackerExtractInfo *info)
 	png_structp png_ptr;
 	png_infop info_ptr;
 	png_infop end_ptr;
-	png_bytepp row_pointers;
+	png_bytep row_data;
 	guint row;
 	png_uint_32 width, height;
 	gint bit_depth, color_type;
@@ -686,20 +694,10 @@ tracker_extract_get_metadata (TrackerExtractInfo *info)
 	/* Read the image. FIXME We should be able to skip this step and
 	 * just get the info from the end. This causes some errors atm.
 	 */
-	row_pointers = g_new0 (png_bytep, height);
-
-	for (row = 0; row < height; row++) {
-		row_pointers[row] = png_malloc (png_ptr,
-		                                png_get_rowbytes (png_ptr,info_ptr));
-	}
-
-	png_read_image (png_ptr, row_pointers);
-
-	for (row = 0; row < height; row++) {
-		png_free (png_ptr, row_pointers[row]);
-	}
-
-	g_free (row_pointers);
+	row_data = png_malloc (png_ptr, png_get_rowbytes (png_ptr, info_ptr));
+	for (row = 0; row < height; row++)
+		png_read_row (png_ptr, row_data, NULL);
+	png_free (png_ptr, row_data);
 
 	png_read_end (png_ptr, end_ptr);
 
